@@ -8,10 +8,8 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package MooseX::CurriedDelegation::Trait::Method::Delegation;
-BEGIN {
-  $MooseX::CurriedDelegation::Trait::Method::Delegation::AUTHORITY = 'cpan:RSRCHBOY';
-}
-$MooseX::CurriedDelegation::Trait::Method::Delegation::VERSION = '0.002';
+our $AUTHORITY = 'cpan:RSRCHBOY';
+$MooseX::CurriedDelegation::Trait::Method::Delegation::VERSION = '0.003';
 # ABSTRACT: A trait for curried delegation methods
 
 use Moose::Role;
@@ -83,7 +81,7 @@ MooseX::CurriedDelegation::Trait::Method::Delegation - A trait for curried deleg
 
 =head1 VERSION
 
-This document describes version 0.002 of MooseX::CurriedDelegation::Trait::Method::Delegation - released May 19, 2014 as part of MooseX-CurriedDelegation.
+This document describes version 0.003 of MooseX::CurriedDelegation::Trait::Method::Delegation - released November 09, 2016 as part of MooseX-CurriedDelegation.
 
 =head1 DESCRIPTION
 
@@ -106,15 +104,10 @@ L<MooseX::CurriedDelegation>
 
 =back
 
-=head1 SOURCE
-
-The development version is on github at L<http://https://github.com/RsrchBoy/moosex-currieddelegation>
-and may be cloned from L<git://https://github.com/RsrchBoy/moosex-currieddelegation.git>
-
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-https://github.com/RsrchBoy/moosex-currieddelegation/issues
+L<https://github.com/RsrchBoy/moosex-currieddelegation/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -128,7 +121,7 @@ Chris Weyl <cweyl@alumni.drew.edu>
 
 =begin html
 
-<a href="https://www.gittip.com/RsrchBoy/"><img src="https://raw.githubusercontent.com/gittip/www.gittip.com/master/www/assets/%25version/logo.png" /></a>
+<a href="https://gratipay.com/RsrchBoy/"><img src="http://img.shields.io/gratipay/RsrchBoy.svg" /></a>
 <a href="http://bit.ly/rsrchboys-wishlist"><img src="http://wps.io/wp-content/uploads/2014/05/amazon_wishlist.resized.png" /></a>
 <a href="https://flattr.com/submit/auto?user_id=RsrchBoy&url=https%3A%2F%2Fgithub.com%2FRsrchBoy%2Fmoosex-currieddelegation&title=RsrchBoy's%20CPAN%20MooseX-CurriedDelegation&tags=%22RsrchBoy's%20MooseX-CurriedDelegation%20in%20the%20CPAN%22"><img src="http://api.flattr.com/button/flattr-badge-large.png" /></a>
 
@@ -139,9 +132,9 @@ rather B<it is simply a very pleasant surprise>. I largely create and release
 works like this because I need them or I find it enjoyable; however, don't let
 that stop you if you feel like it ;)
 
-L<Flattr this|https://flattr.com/submit/auto?user_id=RsrchBoy&url=https%3A%2F%2Fgithub.com%2FRsrchBoy%2Fmoosex-currieddelegation&title=RsrchBoy's%20CPAN%20MooseX-CurriedDelegation&tags=%22RsrchBoy's%20MooseX-CurriedDelegation%20in%20the%20CPAN%22>,
-L<gittip me|https://www.gittip.com/RsrchBoy/>, or indulge my
-L<Amazon Wishlist|http://bit.ly/rsrchboys-wishlist>...  If you so desire.
+L<Flattr|https://flattr.com/submit/auto?user_id=RsrchBoy&url=https%3A%2F%2Fgithub.com%2FRsrchBoy%2Fmoosex-currieddelegation&title=RsrchBoy's%20CPAN%20MooseX-CurriedDelegation&tags=%22RsrchBoy's%20MooseX-CurriedDelegation%20in%20the%20CPAN%22>,
+L<Gratipay|https://gratipay.com/RsrchBoy/>, or indulge my
+L<Amazon Wishlist|http://bit.ly/rsrchboys-wishlist>...  If and *only* if you so desire.
 
 =head1 COPYRIGHT AND LICENSE
 
